==> ffdc-services-1.5-sources.jar: org/odpi/openmetadata/commonservices/ffdc/rest/NameListResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */

package org.odpi.openmetadata.commonservices.ffdc.rest;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;


/**
 * NameListResponse is the response structure used on the OMAS REST API calls that return a
 * list of names as a response.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class NameListResponse extends FFDCResponseBase
{
    private static final long    serialVersionUID = 1L;

    private List<String> names = null;


    /**
     * Default constructor
     */
    public NameListResponse()
    {
        super();
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public NameListResponse(NameListResponse template)
    {
        super(template);

        if (template != null)
        {
            this.names = template.getNames();
        }
    }


    /**
     * Return the name list result.
     *
     * @return list of strings
     */
    public List<String> getNames()
    {
        if (names == null)
        {
            return null;
        }
        else if (names.isEmpty())
        {
            return null;
        }
        else
        {
            return names;
        }
    }


    /**
     * Set up the name list result.
     *
     * @param names list of strings
     */
    public void setNames(List<String> names)
    {
        this.names = names;
    }


    /**
     * JSON-style toString
     *
     * @return return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "NameListResponse{" +
                "names=" + names +
                '}';
    }


    /**
     * Return comparison result based on the content of the properties.
     *
     * @param objectToCompare test object
     * @return result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (!(objectToCompare instanceof NameListResponse))
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        NameListResponse that = (NameListResponse) objectToCompare;
        return Objects.equals(names, that.names);
    }


    /**
     * Return hash code for this object
     *
     * @return int hash code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(names);
    }
}

==> ffdc-services-2.4-sources.jar: org/odpi/openmetadata/commonservices/ffdc/rest/NameListResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */

package org.odpi.openmetadata.commonservices.ffdc.rest;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Arrays;
import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;


/**
 * NameListResponse is the response structure used on the OMAS REST API calls that return a
 * list of names as a response.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class NameListResponse extends FFDCResponseBase
{
    private static final long    serialVersionUID = 1L;

    private List<String> names = null;


    /**
     * Default constructor
     */
    public NameListResponse()
    {
        super();
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public NameListResponse(NameListResponse template)
    {
        super(template);

        if (template != null)
        {
            this.names = template.getNames();
        }
    }


    /**
     * Return the name list result.
     *
     * @return list of strings
     */
    public List<String> getNames()
    {
        if (names == null)
        {
            return null;
        }
        else if (names.isEmpty())
        {
            return null;
        }
        else
        {
            return names;
        }
    }


    /**
     * Set up the name list result.
     *
     * @param names list of strings
     */
    public void setNames(List<String> names)
    {
        this.names = names;
    }


    /**
     * JSON-style toString
     *
     * @return return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "NameListResponse{" +
                "names=" + names +
                ", exceptionClassName='" + getExceptionClassName() + '\'' +
                ", exceptionCausedBy='" + getExceptionCausedBy() + '\'' +
                ", actionDescription='" + getActionDescription() + '\'' +
                ", relatedHTTPCode=" + getRelatedHTTPCode() +
                ", exceptionErrorMessage='" + getExceptionErrorMessage() + '\'' +
                ", exceptionErrorMessageId='" + getExceptionErrorMessageId() + '\'' +
                ", exceptionErrorMessageParameters=" + Arrays.toString(getExceptionErrorMessageParameters()) +
                ", exceptionSystemAction='" + getExceptionSystemAction() + '\'' +
                ", exceptionUserAction='" + getExceptionUserAction() + '\'' +
                ", exceptionProperties=" + getExceptionProperties() +
                '}';
    }


    /**
     * Return comparison result based on the content of the properties.
     *
     * @param objectToCompare test object
     * @return result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (!(objectToCompare instanceof NameListResponse))
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        NameListResponse that = (NameListResponse) objectToCompare;
        return Objects.equals(names, that.names);
    }


    /**
     * Return hash code for this object
     *
     * @return int hash code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(names);
    }
}
